pub struct SegmentMapping {
pub mapping_type: SegmentMappingType,
pub custom_mapping: Option<[u8; 8]>,
}Expand description
Segment mapping configuration for custom 7-segment display wiring
Fields
mapping_type: SegmentMappingTypeThe type of segment mapping being used
custom_mapping: Option<[u8; 8]>Custom bit mapping array (only used when mapping_type is Custom)
Implementations
Sourceimpl SegmentMapping
impl SegmentMapping
Sourcepub fn new(mapping_type: SegmentMappingType) -> Self
pub fn new(mapping_type: SegmentMappingType) -> Self
Create a new segment mapping with a predefined type
Sourcepub fn custom(mapping: [u8; 8]) -> Self
pub fn custom(mapping: [u8; 8]) -> Self
Create a new segment mapping with a custom mapping array
Sourcepub fn get_custom_mapping(&self) -> Option<&[u8; 8]>
pub fn get_custom_mapping(&self) -> Option<&[u8; 8]>
Get the mapping array if it’s custom