DeviceData

Struct DeviceData 

pub struct DeviceData {
Show 19 fields pub device_type_id: u32, pub serial_number: u32, pub device_name: [u8; 30], pub device_type_name: [u8; 30], pub build_date: [u8; 12], pub activation_code: [u8; 8], pub firmware_version_major: u8, pub firmware_version_minor: u8, pub firmware_revision: u8, pub user_id: u8, pub device_type: u8, pub activated_options: u8, pub device_lock_status: u8, pub hw_type: u8, pub fw_type: u8, pub product_id: u8, pub secondary_firmware_version_major: u8, pub secondary_firmware_version_minor: u8, pub device_is_bootloader: u8,
}
Device-specific data

Fields

device_type_id: u32serial_number: u32device_name: [u8; 30]device_type_name: [u8; 30]build_date: [u8; 12]activation_code: [u8; 8]firmware_version_major: u8firmware_version_minor: u8firmware_revision: u8user_id: u8device_type: u8activated_options: u8device_lock_status: u8hw_type: u8fw_type: u8product_id: u8secondary_firmware_version_major: u8secondary_firmware_version_minor: u8device_is_bootloader: u8

Implementations

Source

impl DeviceData

Additional types for testing compatibility

pub fn device_locked(&self) -> bool

pub fn device_features(&self) -> u8

pub fn software_version_string(&self) -> String

Parse and format the software version from bytes 5 and 6 of device data response Byte 5: bits 4-7 = major-1, bits 0-3 = minor Byte 6: revision number Returns formatted version string like “4.7.15”

pub fn device_name(&self) -> String

pub fn device_type_name(&self) -> String

Get the device type name based on hardware ID, device_type_id, or extracted from device_name

pub fn build_date_string(&self) -> String

Get the build date as a string